pub enum StringParseError {
Read(Error),
Parse(FromUtf16Error),
}Variants
Read(Error)
occurs when you get an error while reading the data
Parse(FromUtf16Error)
occurs when the bytes are not a valid UTF-16 string